function xb = incsearch(func,xmin,xmax,ns)
% incsearch: Localizador de raices por bsqueda incremental
%   xb = incsearch(func,xmin,xmax,ns):
%      Encuentra intervalos de variacin de la variable independiente x 
%      cuyos extremos presentan cambios de signo de una funcin real 
%      definida sobre un cierto dominio
% Entradas:
%   func = Nombre de la funcin
%   xmin, xmax = Extremos del intervalo
%   ns = Nmero de subintervalos (default = 50)
% Salidas:
%   xb(k,1) Es el extremo inferior correspondiente al k-simo intervalo 
%   que presenta cambio de signo
%   xb(k,2) Es el extremo superior correspondiente al k-simo intervalo 
%   que presenta cambio de signo
%   Si no se encuentran intervalos, xb = [].

if nargin < 4, ns = 50; end %Si no se ingresa ns, se lo fija en el valor 50

% Bsqueda incremental
x = linspace(xmin,xmax,ns); 
f = func(x);
fplot(func, [xmin,xmax]);
grid
nb=0; xb=[]; %xb es nulo a menos que se detecte un cambio de signo
for k = 1:length(x)-1
  if sign(f(k))~= sign(f(k+1)) %Verifica si se produce un cambio de signo
    nb=nb+1;
    xb(nb,1)=x(k);
    xb(nb,2)=x(k+1);
  end
end
if isempty(xb)    %Informa que no se encontraron intervalos donde la funcin cambia de signo
  disp('No se encontraron intervalos')
  disp('Verificar el intervalo de bsqueda o incrementar ns')
else
  disp('Nmero de subintervalos:') %Muestra el nmero de subintervalos
  disp(nb)
end
